@@ -4,11 +4,11 @@
 #
 # This program demonstrates the indentation cell format.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('cell_indentation.xlsx')
+workbook = xlsxwriter.Workbook('cell_indentation.xlsx')
 
 worksheet = workbook.add_worksheet()
 
