@@ -3,13 +3,13 @@
 # An example of inserting images into a worksheet using the XlsxWriter
 # Python module.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
 
 # Create an new Excel file and add a worksheet.
-workbook = Workbook('images.xlsx')
+workbook = xlsxwriter.Workbook('images.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Widen the first column to make the text clearer.
