@@ -28,6 +28,7 @@ from .utility import xl_cell_to_rowcol
 from xlsxwriter.chart_area import ChartArea
 from xlsxwriter.chart_bar import ChartBar
 from xlsxwriter.chart_column import ChartColumn
+from xlsxwriter.chart_doughnut import ChartDoughnut
 from xlsxwriter.chart_line import ChartLine
 from xlsxwriter.chart_pie import ChartPie
 from xlsxwriter.chart_radar import ChartRadar
@@ -57,6 +58,7 @@ class Workbook(xmlwriter.XMLwriter):
         super(Workbook, self).__init__()
 
         self.filename = filename
+
         self.tmpdir = options.get('tmpdir', None)
         self.date_1904 = options.get('date_1904', False)
         self.strings_to_numbers = options.get('strings_to_numbers', False)
@@ -65,6 +67,10 @@ class Workbook(xmlwriter.XMLwriter):
         self.default_date_format = options.get('default_date_format', None)
         self.optimization = options.get('constant_memory', False)
         self.in_memory = options.get('in_memory', False)
+        self.excel2003_style = options.get('excel2003_style', False)
+        self.default_format_properties = \
+            options.get('default_format_properties', {})
+
         self.worksheet_meta = WorksheetMeta()
         self.selected = 0
         self.fileclosed = 0
@@ -109,13 +115,17 @@ class Workbook(xmlwriter.XMLwriter):
         self.calc_mode = "auto"
         self.calc_on_load = True
         self.allow_zip64 = False
+        self.calc_id = 124519
 
         # We can't do 'constant_memory' mode while doing 'in_memory' mode.
         if self.in_memory:
             self.optimization = False
 
         # Add the default cell format.
-        self.add_format({'xf_index': 0})
+        if self.excel2003_style:
+            self.add_format({'xf_index': 0, 'font_family': 0})
+        else:
+            self.add_format({'xf_index': 0})
 
         # Add a default URL format.
         self.default_url_format = self.add_format({'color': 'blue',
@@ -172,7 +182,15 @@ class Workbook(xmlwriter.XMLwriter):
             Reference to a Format object.
 
         """
-        xf_format = Format(properties,
+        format_properties = self.default_format_properties.copy()
+
+        if self.excel2003_style:
+            format_properties = {'font_name': 'Arial', 'font_size': 10,
+                                 'theme': 1 * -1}
+
+        format_properties.update(properties)
+
+        xf_format = Format(format_properties,
                            self.xf_format_indices,
                            self.dxf_format_indices)
 
@@ -205,6 +223,8 @@ class Workbook(xmlwriter.XMLwriter):
             chart = ChartBar(options)
         elif chart_type == 'column':
             chart = ChartColumn(options)
+        elif chart_type == 'doughnut':
+            chart = ChartDoughnut(options)
         elif chart_type == 'line':
             chart = ChartLine(options)
         elif chart_type == 'pie':
@@ -258,7 +278,7 @@ class Workbook(xmlwriter.XMLwriter):
         """
         self.doc_properties = properties
 
-    def set_calc_mode(self, mode):
+    def set_calc_mode(self, mode, calc_id=None):
         """
         Set the Excel caclcuation mode for the workbook.
 
@@ -279,6 +299,10 @@ class Workbook(xmlwriter.XMLwriter):
         elif mode == 'auto_except_tables':
             self.calc_mode = 'autoNoTable'
 
+        # Leave undocumented for now. Rarely required.
+        if calc_id:
+            self.calc_id = calc_id
+
     def define_name(self, name, formula):
         # Create a defined name in Excel. We handle global/workbook level
         # names and local/worksheet names.
@@ -489,6 +513,7 @@ class Workbook(xmlwriter.XMLwriter):
             'strings_to_urls': self.strings_to_urls,
             'default_date_format': self.default_date_format,
             'default_url_format': self.default_url_format,
+            'excel2003_style': self.excel2003_style,
         }
 
         if is_chartsheet:
@@ -1263,7 +1288,7 @@ class Workbook(xmlwriter.XMLwriter):
 
     def _write_calc_pr(self):
         # Write the <calcPr> element.
-        attributes = [('calcId', '124519')]
+        attributes = [('calcId', self.calc_id)]
 
         if self.calc_mode == 'manual':
             attributes.append(('calcMode', self.calc_mode))
